from typing import Any, Dict, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from dev.thecesrom.helper.types import AnyStr

def addDevice(
    deviceType: AnyStr,
    deviceName: AnyStr,
    deviceProps: Dict[AnyStr, Any],
    description: Optional[AnyStr] = ...,
) -> None: ...
def getDeviceHostname(deviceName: AnyStr) -> AnyStr: ...
def listDevices() -> BasicDataset: ...
def refreshBrowse(deviceName: AnyStr) -> None: ...
def removeDevice(deviceName: AnyStr) -> None: ...
def restart(deviceName: AnyStr) -> None: ...
def setDeviceEnabled(deviceName: AnyStr, enabled: bool) -> None: ...
def setDeviceHostname(deviceName: AnyStr, hostname: AnyStr) -> None: ...
