from typing import List

from com.inductiveautomation.ignition.common.user import User
from com.palantir.ptoss.cinch.core import DefaultBindableModel
from dev.thecesrom.helper.types import AnyStr

class RosterModel(DefaultBindableModel):
    def __init__(self) -> None: ...
    def getName(self) -> AnyStr: ...
    def getUsers(self) -> List[AnyStr]: ...
    def set(self, that: RosterModel) -> None: ...
    def setName(self, name: AnyStr) -> None: ...
    def setUsers(self, users: List[User]) -> None: ...
