from com.inductiveautomation.factorypmi.application import VisionDesktop
from com.inductiveautomation.factorypmi.application.model import TemplateManager
from com.inductiveautomation.factorypmi.application.script.builtin import (
    ClientDatasetUtilities,
    ClientSystemUtilities,
    NavUtilities,
    WindowUtilities,
)
from com.inductiveautomation.factorypmi.application.sqltags.project import (
    ProjectTagManager,
)

class VisionClientContext:
    def getDatasetUtil(self) -> ClientDatasetUtilities: ...
    def getGuiUtil(self) -> WindowUtilities: ...
    def getNavUtil(self) -> NavUtilities: ...
    def getPrimaryDesktop(self) -> VisionDesktop: ...
    def getProjectTags(self) -> ProjectTagManager: ...
    def getSystemUtil(self) -> ClientSystemUtilities: ...
    def getTemplateManager(self) -> TemplateManager: ...
    def getUpdateBase(self) -> int: ...
