from dev.thecesrom.helper.types import AnyStr
from java.lang import Object
from javax.security.auth import Subject

class Principal:
    def equals(self, another: Object) -> bool: ...
    def getName(self) -> AnyStr: ...
    def hashCode(self) -> int: ...
    def implies(self, subject: Subject) -> bool: ...
    def toString(self) -> AnyStr: ...
