from typing import Any

from dev.thecesrom.helper.types import AnyStr
from java.lang import Class, Exception, Object

class ClassNameResolver(Object):
    def __init__(self) -> None: ...
    def addAlias(self, clazz: Class, alias: AnyStr) -> None: ...
    def addDefaults(self) -> None: ...
    def addSearchPath(self, path: AnyStr) -> None: ...
    def classForName(self, name: AnyStr) -> Class: ...
    def createBasic(self) -> ClassNameResolver: ...
    def getName(self, clazz: Class) -> AnyStr: ...

class SerializationException(Exception):
    def __init__(self, *args: Any) -> None: ...
