from typing import Any

from java.lang import Object

class Dimension2D(Object):
    def getHeight(self) -> float: ...
    def getWidth(self) -> float: ...
    def setSize(self, *args: Any) -> None: ...

class Point2D(Object):
    def clone(self) -> Object: ...
    def distance(self, *args: Any) -> float: ...
    def distanceSq(self, *args: Any) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def setLocation(self, *args: Any) -> None: ...

    class Double(Object):
        x: float
        y: float
        def __init__(self, x: float = ..., y: float = ...) -> None: ...
        def clone(self) -> Object: ...
        def distance(self, *args: Any) -> float: ...
        def distanceSq(self, *args: Any) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def setLocation(self, x: float, y: float) -> None: ...

    class Float(Object):
        x: float
        y: float
        def __init__(self, x: float = ..., y: float = ...) -> None: ...
        def clone(self) -> Object: ...
        def distance(self, *args: Any) -> float: ...
        def distanceSq(self, *args: Any) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def setLocation(self, x: float, y: float) -> None: ...
