from typing import Any

from java.lang import Object

class Binding:
    def update(self, *args: Any) -> None: ...

class DefaultBindableModel(Object):
    def __init__(self) -> None: ...
    def bind(self, toBind: Binding) -> None: ...
    def modelUpdated(self, *args: Any) -> None: ...
    def unbind(self, toUnbind: Binding) -> None: ...
    def unbindAll(self) -> None: ...
    def update(self) -> None: ...
