from typing import Any

from java.lang import Object

class DocumentElement(Object):
    def __init__(self, *args: Any) -> None: ...

class Document(DocumentElement):
    def __init__(self, *args: Any) -> None: ...
