from typing import Optional, Tuple

from dev.thecesrom.helper.types import AnyStr
from java.util import EventObject

def getRoles() -> Tuple[AnyStr, ...]: ...
def getUserRoles(
    username: AnyStr, password: AnyStr, authProfile: AnyStr = ..., timeout: int = ...
) -> Optional[Tuple[AnyStr, ...]]: ...
def getUsername() -> AnyStr: ...
def isScreenLocked() -> bool: ...
def lockScreen(obscure: bool = ...) -> None: ...
def logout() -> None: ...
def switchUser(
    username: AnyStr, password: AnyStr, event: EventObject, hideError: bool = ...
) -> bool: ...
def unlockScreen() -> None: ...
def validateUser(
    username: AnyStr, password: AnyStr, authProfile: AnyStr = ..., timeout: int = ...
) -> bool: ...
