from typing import List

from dev.thecesrom.helper.types import AnyStr

def getProjectName() -> AnyStr: ...
def getProjectNames() -> List[AnyStr]: ...
def requestScan(timeout: int = ...) -> None: ...
